==> org.eclipse.scout.sdk.ui.source_3.7.2.201202140505.jar: org/eclipse/scout/sdk/ui/internal/view/outline/pages/project/client/page/PageNodePageHelper.java <==
/*******************************************************************************
 * Copyright (c) 2010 BSI Business Systems Integration AG.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * Contributors:
 *     BSI Business Systems Integration AG - initial API and implementation
 ******************************************************************************/
package org.eclipse.scout.sdk.ui.internal.view.outline.pages.project.client.page;

import java.util.ArrayList;

import org.eclipse.jdt.core.IType;
import org.eclipse.scout.sdk.RuntimeClasses;
import org.eclipse.scout.sdk.ScoutSdk;
import org.eclipse.scout.sdk.ui.view.outline.pages.AbstractPage;
import org.eclipse.scout.sdk.workspace.type.TypeUtility;
import org.eclipse.scout.sdk.workspace.typecache.ITypeHierarchy;

/**
 * <h3>PageNodePageHelper</h3> ...
 */
public class PageNodePageHelper {
  final IType iPageWithNodes = ScoutSdk.getType(RuntimeClasses.IPageWithNodes);
  final IType iPageWithTable = ScoutSdk.getType(RuntimeClasses.IPageWithTable);
  private static final PageNodePageHelper instance = new PageNodePageHelper();

  private PageNodePageHelper() {
  }

  public static AbstractPage[] createRepresentationFor(AbstractPage parentPage, IType[] types, ITypeHierarchy pageTypeHierarchy) {
    return instance.createRepresentationForImpl(parentPage, types, pageTypeHierarchy);
  }

  private AbstractPage[] createRepresentationForImpl(AbstractPage parentPage, IType[] types, ITypeHierarchy pageTypeHierarchy) {
    ArrayList<AbstractPage> pages = new ArrayList<AbstractPage>();
    for (IType type : types) {
      if (TypeUtility.exists(type)) {
        if (pageTypeHierarchy.isSubtype(iPageWithNodes, type)) {
          // create page with node
          pages.add(new PageWithNodeNodePage(parentPage, type));
        }
        else if (pageTypeHierarchy.isSubtype(iPageWithTable, type)) {
          // create page with table
          pages.add(new PageWithTableNodePage(parentPage, type));
        }
        else {
          pages.add(new PageNodePage(parentPage, type));
        }
      }
    }
    return pages.toArray(new AbstractPage[pages.size()]);
  }
}

==> org.eclipse.scout.sdk.ui.source_3.8.2.201302111336.jar: org/eclipse/scout/sdk/ui/internal/view/outline/pages/project/client/page/PageNodePageHelper.java <==
/*******************************************************************************
 * Copyright (c) 2010 BSI Business Systems Integration AG.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *     BSI Business Systems Integration AG - initial API and implementation
 ******************************************************************************/
package org.eclipse.scout.sdk.ui.internal.view.outline.pages.project.client.page;

import java.util.ArrayList;

import org.eclipse.jdt.core.IType;
import org.eclipse.scout.sdk.RuntimeClasses;
import org.eclipse.scout.sdk.ui.view.outline.pages.AbstractPage;
import org.eclipse.scout.sdk.util.type.TypeUtility;
import org.eclipse.scout.sdk.util.typecache.ITypeHierarchy;

/**
 * <h3>PageNodePageHelper</h3> ...
 */
public class PageNodePageHelper {

  private PageNodePageHelper() {
  }

  public static AbstractPage[] createRepresentationFor(AbstractPage parentPage, IType[] types, ITypeHierarchy pageTypeHierarchy) {
    ArrayList<AbstractPage> pages = new ArrayList<AbstractPage>();
    for (IType type : types) {
      if (TypeUtility.exists(type)) {
        if (pageTypeHierarchy.isSubtype(TypeUtility.getType(RuntimeClasses.IPageWithNodes), type)) {
          // create page with node
          pages.add(new PageWithNodeNodePage(parentPage, type));
        }
        else if (pageTypeHierarchy.isSubtype(TypeUtility.getType(RuntimeClasses.IPageWithTable), type)) {
          // create page with table
          pages.add(new PageWithTableNodePage(parentPage, type));
        }
        else {
          pages.add(new PageNodePage(parentPage, type));
        }
      }
    }
    return pages.toArray(new AbstractPage[pages.size()]);
  }
}
